Type Alias StatelessValidationFn
pub type StatelessValidationFn<T> = Arc<dyn Fn(TransactionOrigin, &T) -> Result<(), InvalidPoolTransactionError> + Sync + Send>;Expand description
Additional stateless validation function signature.
Receives the transaction origin and a reference to the transaction. Returns Ok(()) if the
transaction passes or Err to reject it.
Aliased Type
pub struct StatelessValidationFn<T> { /* private fields */ }Layout
Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.
Size: 16 bytes